@@ -57,13 +57,13 @@ struct _GstRegistryClass {
   GstObjectClass        parent_class;
 };
 
-GST_EXPORT
+GST_API
 GType                   gst_registry_get_type           (void);
 
-GST_EXPORT
+GST_API
 GstRegistry *           gst_registry_get                (void);
 
-GST_EXPORT
+GST_API
 gboolean                gst_registry_scan_path          (GstRegistry *registry, const gchar *path);
 
 #if 0
@@ -71,53 +71,53 @@ void                    gst_registry_add_path           (GstRegistry * registry,
 GList*                  gst_registry_get_path_list      (GstRegistry *registry);
 #endif
 
-GST_EXPORT
+GST_API
 gboolean                gst_registry_add_plugin         (GstRegistry *registry, GstPlugin *plugin);
 
-GST_EXPORT
+GST_API
 void                    gst_registry_remove_plugin      (GstRegistry *registry, GstPlugin *plugin);
 
-GST_EXPORT
+GST_API
 gboolean                gst_registry_add_feature        (GstRegistry * registry, GstPluginFeature * feature);
 
-GST_EXPORT
+GST_API
 void                    gst_registry_remove_feature     (GstRegistry * registry, GstPluginFeature * feature);
 
-GST_EXPORT
+GST_API
 GList*                  gst_registry_get_plugin_list    (GstRegistry *registry);
 
-GST_EXPORT
+GST_API
 GList*                  gst_registry_plugin_filter      (GstRegistry *registry,
                                                          GstPluginFilter filter,
                                                          gboolean first,
                                                          gpointer user_data);
-GST_EXPORT
+GST_API
 GList*                  gst_registry_feature_filter     (GstRegistry *registry,
                                                          GstPluginFeatureFilter filter,
                                                          gboolean first,
                                                          gpointer user_data);
-GST_EXPORT
+GST_API
 GList *                 gst_registry_get_feature_list   (GstRegistry *registry,
                                                          GType type);
-GST_EXPORT
+GST_API
 GList *                 gst_registry_get_feature_list_by_plugin (GstRegistry *registry, const gchar *name);
 
-GST_EXPORT
+GST_API
 guint32                 gst_registry_get_feature_list_cookie (GstRegistry *registry);
 
-GST_EXPORT
+GST_API
 GstPlugin*              gst_registry_find_plugin        (GstRegistry *registry, const gchar *name);
 
-GST_EXPORT
+GST_API
 GstPluginFeature*       gst_registry_find_feature       (GstRegistry *registry, const gchar *name, GType type);
 
-GST_EXPORT
+GST_API
 GstPlugin *             gst_registry_lookup             (GstRegistry *registry, const char *filename);
 
-GST_EXPORT
+GST_API
 GstPluginFeature *      gst_registry_lookup_feature     (GstRegistry *registry, const char *name);
 
-GST_EXPORT
+GST_API
 gboolean                gst_registry_check_feature_version (GstRegistry *registry,
                                                             const gchar *feature_name,
                                                             guint        min_major,
